###################################################
### chunk number 1: 
###################################################
options(prompt= "R> ", useFancyQuotes = FALSE)


###################################################
### chunk number 2: 
###################################################
library("mlogit")
#source("~/Forge/mlogit/chargement.R")
data("Heating", package = "mlogit")
H <- mlogit.data(Heating, shape="wide", choice="depvar", varying=c(3:12))
m <- mlogit(depvar~ic+oc|0, H)
summary(m)


###################################################
### chunk number 3: 
###################################################
apply(fitted(m, outcome=FALSE), 2, mean)


###################################################
### chunk number 4: 
###################################################
coef(m)["oc"]/coef(m)["ic"]


###################################################
### chunk number 5: 
###################################################
H$lcc=H$ic+H$oc/0.12
mlcc <- mlogit(depvar~lcc|0, H)
lrtest(m, mlcc)
qchisq(0.05, df = 1, lower.tail = FALSE)


###################################################
### chunk number 6: 
###################################################
mc <- mlogit(depvar~ic+oc, H, reflevel = 'hp')
summary(mc)
apply(fitted(mc, outcome = FALSE), 2, mean)


###################################################
### chunk number 7: 
###################################################
wtp <- coef(mc)["oc"]/coef(mc)["ic"]
wtp
r <- 1/wtp
r


###################################################
### chunk number 8: 
###################################################
update(mc, reflevel="gr")


###################################################
### chunk number 9: 
###################################################
mi <- mlogit(depvar~oc+I(ic/income), H)
summary(mi)


###################################################
### chunk number 10: 
###################################################
mi2 <- mlogit(depvar~oc+ic|income, H, reflevel="hp")


###################################################
### chunk number 11: 
###################################################
lrtest(mc, mi2)
waldtest(mc, mi2)
scoretest(mc, mi2)


###################################################
### chunk number 12: 
###################################################
X <- model.matrix(mc)
alt <- index(H)$alt
chid <- index(H)$chid
eXb <- as.numeric(exp(X %*% coef(mc)))
SeXb <- tapply(eXb, chid, sum)
P <- eXb / SeXb[chid]
P <- matrix(P, ncol = 5, byrow = TRUE)
head(P)
apply(P, 2, mean)


###################################################
### chunk number 13: 
###################################################
X <- model.matrix(mc)
X[alt == "hp", "ic"] <- X[alt == "hp", "ic"] * 0.90
eXb <- as.numeric(exp(X %*% coef(mc)))
SeXb <- tapply(eXb, chid, sum)
P <- eXb / SeXb[chid]
P <- matrix(P, ncol = 5, byrow=TRUE)
apply(P, 2, mean)


###################################################
### chunk number 14: 
###################################################
X <- model.matrix(mc)
Xn <- X[alt == "ec",]
Xn[, "ic"] <- Xn[, "ic"] + 200
Xn[, "oc"] <- Xn[, "oc"] * 0.75
unchid <- unique(index(H)$chid)
rownames(Xn) <- paste(unchid, 'new', sep = ".")
chidb <- c(chid, unchid)
X <- rbind(X, Xn)
X <- X[order(chidb), ]
eXb <- as.numeric(exp(X %*% coef(mc)))
SeXb <- as.numeric(tapply(eXb, sort(chidb), sum))
P <- eXb / SeXb[sort(chidb)]
P <- matrix(P, ncol = 6, byrow = TRUE)
apply(P, 2, mean)


###################################################
### chunk number 15: 
###################################################
library("mlogit")
data("HC", package = "mlogit")
HC <- mlogit.data(HC, varying = c(2:8, 10:16), choice = "depvar", shape = "wide")
cooling.modes <- index(HC)$alt %in% c('gcc', 'ecc', 'erc', 'hpc')
room.modes <- index(HC)$alt %in% c('erc', 'er')
# installation / operating costs for cooling are constants, 
# only relevant for mixed systems
HC$icca[!cooling.modes] <- 0
HC$occa[!cooling.modes] <- 0
# create income variables for two sets cooling and rooms
HC$inc.cooling <- HC$inc.room <- 0
HC$inc.cooling[cooling.modes] <- HC$income[cooling.modes]
HC$inc.room[room.modes] <- HC$income[room.modes]
# create an intercet for cooling modes
HC$int.cooling <- as.numeric(cooling.modes)
# estimate the model with only one nest elasticity
nl <- mlogit(depvar ~ ich + och +icca + occa + inc.room + inc.cooling + int.cooling | 0, HC,
             nests = list(cooling = c('gcc','ecc','erc','hpc'), 
             other = c('gc', 'ec', 'er')), un.nest.el = TRUE)
summary(nl)


###################################################
### chunk number 16: 
###################################################
 (coef(nl)['iv']-1)/sqrt(vcov(nl)['iv', 'iv'])


###################################################
### chunk number 17: 
###################################################
# First estimate the multinomial logit model
ml <- update(nl, nests = NULL)
lrtest(nl, ml)


###################################################
### chunk number 18: 
###################################################
nl2 <- update(nl, nests = list(central = c('ec', 'ecc', 'gc', 'gcc', 'hpc'), 
                    room = c('er', 'erc')))
summary(nl2)


###################################################
### chunk number 19: 
###################################################
 (coef(nl2)['iv']-1)/sqrt(vcov(nl2)['iv', 'iv'])
lrtest(nl2, ml)


###################################################
### chunk number 20: 
###################################################
logLik(nl)
logLik(nl2)


###################################################
### chunk number 21: 
###################################################
nl3 <- update(nl, un.nest.el = FALSE)


###################################################
### chunk number 22: 
###################################################
lrtest(nl, nl3)


###################################################
### chunk number 23: 
###################################################
nl4 <- update(nl, nests=list(n1 = c('gcc', 'ecc', 'erc'), n2 = c('hpc'),
                    n3 = c('gc', 'ec', 'er')))
summary(nl4)


###################################################
### chunk number 24: 
###################################################
library("mlogit")
data("Electricity", package = "mlogit")
Electr <- mlogit.data(Electricity, id="id", choice="choice", 
                      varying=3:26, shape="wide", sep="")


###################################################
### chunk number 25:  eval=FALSE
###################################################
## Elec.mxl <- mlogit(choice~pf+cl+loc+wk+tod+seas|0, Electr, 
##               rpar=c(pf='n', cl='n', loc='n', wk='n', tod='n', seas='n'), 
##               R=100, halton=NA, print.level=0, panel=TRUE)


###################################################
### chunk number 26: 
###################################################
data("MixedExamples", package = "mlogit")


###################################################
### chunk number 27: 
###################################################
summary(Elec.mxl)


###################################################
### chunk number 28: 
###################################################
coef(Elec.mxl)['cl']/coef(Elec.mxl)['pf']


###################################################
### chunk number 29: 
###################################################
pnorm(-coef(Elec.mxl)['cl']/coef(Elec.mxl)['sd.cl'])


###################################################
### chunk number 30: 
###################################################
pnorm(-coef(Elec.mxl)['pf']/coef(Elec.mxl)['sd.pf'])


###################################################
### chunk number 31:  eval=FALSE
###################################################
## Elec.mxl2 <- mlogit(choice~pf+cl+loc+wk+tod+seas|0, Electr, 
##                    rpar=c(cl='n', loc='n', wk='n', tod='n', seas='n'), 
##                    R=100, halton=NA, print.level=0, panel=TRUE)


###################################################
### chunk number 32: 
###################################################
summary(Elec.mxl2)


###################################################
### chunk number 33:  eval=FALSE
###################################################
## Elec.mxl3 <- update(Elec.mxl, rpar=c(cl='n', loc='n', wk='u', tod='n', seas='n'))


###################################################
### chunk number 34: 
###################################################
summary(Elec.mxl3)
rpar(Elec.mxl3, 'wk')
summary(rpar(Elec.mxl3, 'wk'))


###################################################
### chunk number 35: 
###################################################
plot(rpar(Elec.mxl3, 'wk'))


###################################################
### chunk number 36:  eval=FALSE
###################################################
## Electr <- mlogit.data(Electricity, id="id", choice="choice", 
##                       varying=3:26, shape="wide", sep="",
##                       opposite=c('tod', 'seas'))
## Elec.mxl4 <- mlogit(choice~pf+cl+loc+wk+tod+seas|0, Electr, 
##               rpar=c(cl='n', loc='n', wk='u', tod='ln', seas='ln'), 
##               R=100, halton=NA, print.level=0, panel=TRUE)


###################################################
### chunk number 37: 
###################################################
summary(Elec.mxl4)


###################################################
### chunk number 38: 
###################################################
plot(rpar(Elec.mxl4, 'seas'))


###################################################
### chunk number 39:  eval=FALSE
###################################################
## Elec.mxl5 <- update(Elec.mxl4, correlation = TRUE)


###################################################
### chunk number 40: 
###################################################
summary(Elec.mxl5)
cor.mlogit(Elec.mxl5)
lrtest(Elec.mxl5, Elec.mxl4)
waldtest(Elec.mxl5, correlation = FALSE)
scoretest(Elec.mxl4, correlation = TRUE)


